# AI Experiment Studio

# config 
from aistudio.utils import ConfigHandler

class AIStudio():
    def __init__(self, train_fn, config, file_name = './AIStudio', tb_path = './tests/test0'):
        self.train_fn = train_fn # external running function
        self.base_conf = config
        self.file_name = file_name # name of the file to write run configs
        self.tb_path = tb_path # path to the tensorboard

        # all the lists to vary for my experiments
        self.configs = [] # list of all the configuration to run the experiments
        self.seeds = [] # list of all the seeds to give to the model
        self.maxlen = [] # list of all maxlen to test
        self.minlen = [] # list of all minlen to test
        self.batch_size = [] # list of all the batchsizes

        assert len(self.maxlen) == len(self.minlen) # to check if we have same sets

    def _make_config(self):
        # function to return the ConfigurationHandler
        cnt = 0
        for seed in self.seeds:
            for maxl, minl in zip(self.maxlen, self.minlen):
                config = ConfigHandler(self.base_conf)
                config.maxlen = maxl
                config.minlen = minl
                config.seed = seed
                config.add('tb_path', self.tb_path)
                config.add('exp_num', cnt)
                cnt += 1

                self.config.append(config)

    def add(self, key, val):
        setattr(self, key, val)

    def run(self):
        for i, config in self.configs:
            config.file_name = '{0}_{1}.txt'.format(self.file_name, i)
            self.train_fn(config)


# utils file having the config handler

# class for configurations
class ConfigHandler():
    def __init__(self, config_dict):
        # rather than individually setting the values, iterate
        for k, v in config_dict.items():
            setattr(self, k, v)

    def add(self, key, val):
        setattr(self, key, val)

    def set_val(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)

    def get_txt(self):
        t_ =  '***** CONFIGURATION *****\n'
        t_ += 'seed value: {}\n'.format(config.seed)
        t_ += 'maxlen:     {}\n'.format(config.maxlen)
        t_ += 'minlen:     {}\n'.format(config.minlen)
        t_ += 'batch size: {}\n'.format(config.batch_size)
        t_ += 'epochs:     {}\n'.format(config.num_epochs)
        t_ += 'gen-pre-n:  {}\n'.format(config.gen_pre_train)
        t_ += 'dis-pre-n:  {}\n'.format(config.dis_pre_train)
        t_ += '*************************\n'.format(config.gen_pre_train)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name='aistudio',
      version='0.0.1',
      author="Yash Bonde",
      author_email="bonde.yash97@gmail.com",
      description="A Simple program to Handle AI Research Needs",
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/yashbonde/aistudio",
      packages=setuptools.find_packages(),
      classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        ]
    )
